@@ -236,7 +236,7 @@ static void
 _set_reporting_level_for_name (GstValidateRunner * runner,
     const gchar * pattern, GstValidateReportingDetails level)
 {
-  PatternLevel *pattern_level = g_malloc (sizeof (PatternLevel));
+  PatternLevel *pattern_level = g_new (PatternLevel, 1);
   GPatternSpec *pattern_spec = g_pattern_spec_new (pattern);
 
   pattern_level->pattern = pattern_spec;
@@ -445,6 +445,7 @@ gst_validate_runner_init (GstValidateRunner * runner)
 {
   runner->priv = gst_validate_runner_get_instance_private (runner);
 
+  g_mutex_init (&runner->priv->mutex);
   runner->priv->reports_by_type = g_hash_table_new (g_direct_hash,
       g_direct_equal);
 
